==> hussar-skins-1.7.0.jar: static/js/getPwd.js <==
/**
 * @Description: 定义找回密码页面脚本文件
 * @Author: LiangDong
 * @Date: 2018/4/18.
 */

layui.use(['jquery','layer','Hussar','jstree','HussarAjax','form','HussarSecurity'], function(){
	var Hussar = layui.Hussar;
	var $ = layui.jquery;
	var layer = layui.layer;
	var $ax = layui.HussarAjax;
	var form = layui.form;	
	var Security = new layui.HussarSecurity();	
	var GetPwd = {		    
		    layerIndex: -1,
		    userAccount: null,
			pQues: null,
			pKey: null
		};
	
	/**
	 * 验证用户名
	 * 如果正确并返回问题
	 */
	GetPwd.validateAccount = function () {
		var userAccount = $("#userAccount").val();
		var kaptcha = $("#kaptcha").val();
		var ajax = new $ax(Hussar.ctxPath + "/getBackPwd/getQues",
				function(data) {			
					if (data.code == "200") {						
						$("input[name='pQues']").val(data.message);		
						$("#idArea").addClass("hide");
						$("#quesArea").removeClass("hide");							
						GetPwd.userAccount = userAccount;
                        $("input[name='userAccount']").val(userAccount);
                    } else if (data.code) {
						Hussar.error(data.message);
					}
				}, 
				function(data) {
					Hussar.error("保存失败!");
				});		
		ajax.set("userAccount", userAccount);
		ajax.set("kaptcha", kaptcha);
		ajax.start();
	};
	
	/**
	 * 验证问题答案
	 */
	GetPwd.validateKey = function () {
        GetPwd.pQues = $("#pQues").val();
        GetPwd.pKey = $("#pKey").val();
		var ajax = new $ax(Hussar.ctxPath + "/getBackPwd/validateKey",
				function(data) {			
					if (data.code == "200") {						
						$("#quesArea").addClass("hide");
						$("#pwdArea").removeClass("hide");							
					} else if (data.code) {
						Hussar.error(data.message);
					}
				}, 
				function(data) {
					Hussar.error("保存失败!");
				});		
		ajax.set("userAccount", GetPwd.userAccount);
		ajax.set("pQues", GetPwd.pQues);
		ajax.set("pKey", GetPwd.pKey);
		ajax.start();
	};
	
	/**
	 * 设置新密码
	 */
	GetPwd.setNewPwd = function () {
		var data = Security.encode($("#pwdForm").serialize());//调用加密方法进行加密

		var ajax = new $ax(Hussar.ctxPath + "/getBackPwd/setNewPwd",
				function(data) {			
					if (data.code == "200") {						
						GetPwd.toLogin();
					} else if (data.code) {
						Hussar.error(data.message);
					}
				}, 
				function(data) {
					Hussar.error("保存失败!");
				});
		ajax.set("data", data);
        ajax.set("pQues", GetPwd.pQues);
        ajax.set("pKey", GetPwd.pKey);
		ajax.start();
	};
	
	/**
	 * 去登录
	 */
	GetPwd.toLogin = function () {
        var operation = function () {
            window.location.href = Hussar.ctxPath+"/login";
        };
        Hussar.confirm("密码修改成功，请重新登录。", operation);
	};
	
	
	/**
	 * 初始化按钮事件
	 */
	GetPwd.initButtonEvent = function () {		
		
		//保存用户名和验证码按钮事件
		$("#save1").click(function(){
			form.on('submit(account)', function(data){
				GetPwd.validateAccount();
			});	
		});
		
		//保存问题答案按钮事件
		$("#save2").click(function(){
			form.on('submit(key)', function(data){
				GetPwd.validateKey();
			});	
		});
		
		//保存设置新密码按钮事件
		$("#save3").click(function(){
			form.on('submit(pwd)', function(data){
				GetPwd.setNewPwd();
			});	
		});
		
		//点击验证码图片
		$("#kaptchaImg").click(function(){			
			$("#kaptchaImg").attr('src', '/kaptcha?' + Math.floor(Math.random() * 100)).fadeIn();
		});
		
	};
	
	/**
	 * 初始化表单验证
	 */
	GetPwd.initValidate = function () {
		form.verify({
			pwd: [/^[\S]{6,12}$/ , '密码必须6到12位，且不能出现空格'] 
		});
	};
	

	$(function () { 
		GetPwd.initButtonEvent();	//	初始化按钮事件
		GetPwd.initValidate();	//初始化表单验证
	});	
	
});

==> hussar-skins-2.0.5.jar: static/js/getPwd.js <==
/**
 * @Description: 定义找回密码页面脚本文件
 * @Author: LiangDong
 * @Date: 2018/4/18.
 */

layui.use(['jquery','layer','Hussar','jstree','HussarAjax','form','HussarSecurity'], function(){
	var Hussar = layui.Hussar;
	var $ = layui.jquery;
	var layer = layui.layer;
	var $ax = layui.HussarAjax;
	var form = layui.form;	
	var Security = new layui.HussarSecurity();	
	var GetPwd = {		    
		    layerIndex: -1,
		    userAccount: null,
			pQues: null,
			pKey: null
		};
	
	/**
	 * 验证用户名
	 * 如果正确并返回问题
	 */
	GetPwd.validateAccount = function () {
		var userAccount = $("#userAccount").val();
		var kaptcha = $("#kaptcha").val();
		var ajax = new $ax(Hussar.ctxPath + "/getBackPwd/getQues",
				function(data) {			
					if (data.code == "200") {						
						$("input[name='pQues']").val(data.message);		
						$("#idArea").addClass("hide");
						$("#quesArea").removeClass("hide");							
						GetPwd.userAccount = userAccount;
                        $("input[name='userAccount']").val(userAccount);
                    } else if (data.code) {
						Hussar.error(data.message);
					}
				}, 
				function(data) {
					Hussar.error("验证失败!");
				});		
		ajax.set("userAccount", userAccount);
		ajax.set("kaptcha", kaptcha);
		ajax.start();
	};
	
	/**
	 * 验证问题答案
	 */
	GetPwd.validateKey = function () {
        GetPwd.pQues = $("#pQues").val();
        GetPwd.pKey = $("#pKey").val();
		var ajax = new $ax(Hussar.ctxPath + "/getBackPwd/validateKey",
				function(data) {			
					if (data.code == "200") {						
						$("#quesArea").addClass("hide");
						$("#pwdArea").removeClass("hide");							
					} else if (data.code) {
						Hussar.error(data.message);
					}
				}, 
				function(data) {
					Hussar.error("验证失败!");
				});		
		ajax.set("userAccount", Security.encode(GetPwd.userAccount));
		ajax.set("pQues", Security.encode(GetPwd.pQues));
		ajax.set("pKey", Security.encode(GetPwd.pKey));
		ajax.start();
	};
	
	/**
	 * 设置新密码
	 */
	GetPwd.setNewPwd = function () {
		var data = Security.encode($("#pwdForm").serialize());//调用加密方法进行加密

		var ajax = new $ax(Hussar.ctxPath + "/getBackPwd/setNewPwd",
				function(data) {			
					if (data.code == "200") {						
						GetPwd.toLogin();
					} else if (data.code) {
						Hussar.error(data.message);
					}
				}, 
				function(data) {
					Hussar.error("保存失败!");
				});
		ajax.set("data", data);
		ajax.set("pQues", Security.encode(GetPwd.pQues));
		ajax.set("pKey", Security.encode(GetPwd.pKey));
		ajax.start();
	};
	
	/**
	 * 去登录
	 */
	GetPwd.toLogin = function () {
        var operation = function () {
            window.location.href = Hussar.ctxPath+"/login";
        };
        Hussar.confirm("密码修改成功，请重新登录。", operation);
	};
	
	
	/**
	 * 初始化按钮事件
	 */
	GetPwd.initButtonEvent = function () {		
		
		//保存用户名和验证码按钮事件
		$("#save1").click(function(){
			form.on('submit(account)', function(data){
				GetPwd.validateAccount();
			});	
		});
		
		//保存问题答案按钮事件
		$("#save2").click(function(){
			form.on('submit(key)', function(data){
				GetPwd.validateKey();
			});	
		});
		
		//保存设置新密码按钮事件
		$("#save3").click(function(){
			form.on('submit(pwd)', function(data){
				GetPwd.setNewPwd();
			});	
		});
		
		//点击验证码图片
		$("#kaptchaImg").click(function(){			
			$("#kaptchaImg").attr('src', '/kaptcha?' + Math.floor(Math.random() * 100)).fadeIn();
		});
		
	};
	
	/**
	 * 初始化表单验证
	 */
	GetPwd.initValidate = function () {
		form.verify({
			pwd: [/^[\S]{6,12}$/ , '密码必须6到12位，且不能出现空格'] 
		});
	};
	

	$(function () { 
		GetPwd.initButtonEvent();	//	初始化按钮事件
		GetPwd.initValidate();	//初始化表单验证
	});	
	
});
